@@ -10,8 +10,3 @@
 #' @references R package Platypus:https://doi.org/10.1093/nargab/lqab023
 'Bcell_tree_2'
 
-#' Example repertoire for testing and examples
-#'
-#' @name new
-'new'
-
